@@ -61,7 +61,10 @@ new CloudFrontToS3(scope: Construct, id: string, props: CloudFrontToS3Props);
 | **Name**     | **Type**        | **Description** |
 |:-------------|:----------------|-----------------|
 |cloudFrontWebDistribution|[`cloudfront.CloudFrontWebDistribution`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-cloudfront.CloudFrontWebDistribution.html)|Returns an instance of cloudfront.CloudFrontWebDistribution created by the construct|
-|s3Bucket|[`s3.Bucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.Bucket.html)|Returns an instance of s3.Bucket created by the construct|
+|edgeLambdaFunctionVersion|[`lambda.Version`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.Version.html)|Returns an instance of the edge Lambda function version created by the pattern.|
+|cloudFrontLoggingBucket|[`s3.Bucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/aws-s3-readme.html)|Returns an instance of the logging bucket for CloudFront WebDistribution.|
+|s3Bucket|[`s3.Bucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.Bucket.html)|Returns an instance of s3.Bucket created by the construct.|
+|s3LoggingBucket?|[`s3.Bucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.Bucket.html)|Returns an instance of s3.Bucket created by the construct as the logging bucket for the primary bucket.|
 
 ## Default settings
 
@@ -102,6 +105,7 @@ import publication
 from ._jsii import *
 
 import aws_cdk.aws_cloudfront
+import aws_cdk.aws_lambda
 import aws_cdk.aws_s3
 import aws_cdk.core
 
@@ -157,6 +161,23 @@ class CloudFrontToS3(
     def s3_bucket(self) -> aws_cdk.aws_s3.Bucket:
         return jsii.get(self, "s3Bucket")
 
+    @builtins.property
+    @jsii.member(jsii_name="cloudFrontLoggingBucket")
+    def cloud_front_logging_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
+        return jsii.get(self, "cloudFrontLoggingBucket")
+
+    @builtins.property
+    @jsii.member(jsii_name="edgeLambdaFunctionVersion")
+    def edge_lambda_function_version(
+        self,
+    ) -> typing.Optional[aws_cdk.aws_lambda.Version]:
+        return jsii.get(self, "edgeLambdaFunctionVersion")
+
+    @builtins.property
+    @jsii.member(jsii_name="s3LoggingBucket")
+    def s3_logging_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
+        return jsii.get(self, "s3LoggingBucket")
+
 
 @jsii.data_type(
     jsii_type="@aws-solutions-constructs/aws-cloudfront-s3.CloudFrontToS3Props",
